@@ -5,7 +5,9 @@
 */
 #pragma once
 
-#include <KQuickAddons/ManagedConfigModule>
+#include <QTimer>
+
+#include <KQuickManagedConfigModule>
 
 #include "output_model.h"
 
@@ -18,7 +20,7 @@ class ConfigHandler;
 class OrientationSensor;
 class OutputIdentifier;
 
-class KCMKScreen : public KQuickAddons::ManagedConfigModule
+class KCMKScreen : public KQuickManagedConfigModule
 {
     Q_OBJECT
 
@@ -29,12 +31,13 @@ class KCMKScreen : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(bool xwaylandClientsScaleSupported READ xwaylandClientsScaleSupported NOTIFY xwaylandClientsScaleSupportedChanged)
     Q_PROPERTY(bool primaryOutputSupported READ primaryOutputSupported NOTIFY primaryOutputSupportedChanged)
     Q_PROPERTY(bool outputReplicationSupported READ outputReplicationSupported NOTIFY outputReplicationSupportedChanged)
+    Q_PROPERTY(bool tearingSupported READ tearingSupported NOTIFY tearingSupportedChanged)
     Q_PROPERTY(qreal globalScale READ globalScale WRITE setGlobalScale NOTIFY globalScaleChanged)
-    Q_PROPERTY(int outputRetention READ outputRetention WRITE setOutputRetention NOTIFY outputRetentionChanged)
     Q_PROPERTY(bool autoRotationSupported READ autoRotationSupported NOTIFY autoRotationSupportedChanged)
     Q_PROPERTY(bool orientationSensorAvailable READ orientationSensorAvailable NOTIFY orientationSensorAvailableChanged)
     Q_PROPERTY(bool tabletModeAvailable READ tabletModeAvailable NOTIFY tabletModeAvailableChanged)
     Q_PROPERTY(bool xwaylandClientsScale READ xwaylandClientsScale WRITE setXwaylandClientsScale NOTIFY xwaylandClientsScaleChanged)
+    Q_PROPERTY(bool tearingAllowed READ allowTearing WRITE setAllowTearing NOTIFY tearingAllowedChanged)
 
 public:
     enum InvalidConfigReason {
@@ -43,8 +46,7 @@ public:
     };
     Q_ENUM(InvalidConfigReason)
 
-    explicit KCMKScreen(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-    ~KCMKScreen() override = default;
+    explicit KCMKScreen(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
@@ -72,8 +74,9 @@ public:
     void setXwaylandClientsScale(bool scale);
     bool xwaylandClientsScaleSupported() const;
 
-    int outputRetention() const;
-    void setOutputRetention(int retention);
+    void setAllowTearing(bool allow);
+    bool allowTearing() const;
+    bool tearingSupported() const;
 
     bool autoRotationSupported() const;
     bool orientationSensorAvailable() const;
@@ -96,7 +99,6 @@ Q_SIGNALS:
     void primaryOutputSupportedChanged();
     void outputReplicationSupportedChanged();
     void globalScaleChanged();
-    void outputRetentionChanged();
     void autoRotationSupportedChanged();
     void orientationSensorAvailableChanged();
     void tabletModeAvailableChanged();
@@ -108,6 +110,8 @@ Q_SIGNALS:
     void showRevertWarning();
     void xwaylandClientsScaleChanged();
     void xwaylandClientsScaleSupportedChanged();
+    void tearingSupportedChanged();
+    void tearingAllowedChanged();
 
 private:
     void setBackendReady(bool error);
